use serde::Serialize;
use wasm_bindgen::prelude::wasm_bindgen;

pub mod cam16jch;
pub mod hsl;
pub mod oklch;
pub mod rgb;

#[derive(Debug, Clone, Copy, Serialize)]
#[wasm_bindgen]
pub struct Differ {
    pub delta: f32,
    pub percent: f32,
}

#[wasm_bindgen]
impl Differ {
    #[wasm_bindgen(constructor)]
    pub fn new(delta: f32, percent: f32) -> Self {
        Self { delta, percent }
    }
}

pub trait ColorDifference {
    type Difference;

    fn difference(&self, other: &Self) -> Self::Difference;
    fn difference_relative(&self, other: &Self) -> Self::Difference;
}
