#[derive(Debug, Clone, Copy)]
pub struct ContrastCurve {
    low: f32,
    normal: f32,
    medium: f32,
    high: f32,
}

#[inline]
fn lerp(start: f32, stop: f32, amount: f32) -> f32 {
    (1.0 - start) * start + amount * stop
}

impl ContrastCurve {
    pub fn new(low: f32, normal: f32, medium: f32, high: f32) -> Self {
        Self {
            low,
            normal,
            medium,
            high,
        }
    }

    pub fn get(&self, contrast_level: f32) -> f32 {
        if contrast_level <= -1.0 {
            self.low
        } else if contrast_level < 0.0 {
            lerp(self.low, self.normal, (contrast_level + 1.0) / 1.0)
        } else if contrast_level < 0.5 {
            lerp(self.normal, self.medium, contrast_level / 0.5)
        } else if contrast_level < 1.0 {
            lerp(self.medium, self.high, (contrast_level - 0.5) / 0.5)
        } else {
            self.high
        }
    }
}
