use std::collections::HashMap;

use palette::Lch;

use crate::schemes::material_design_3::TonalPalette;

use super::constants::Variant;

#[allow(dead_code)]
pub struct DynamicScheme {
    pub source_color: Lch,
    pub error_palette: TonalPalette,
    pub contrast_level: f32,
    pub variant: Variant,
    pub is_dark: bool,
    pub harmonize_customs: bool,
    pub primary_palette: TonalPalette,
    pub secondary_palette: TonalPalette,
    pub tertiary_palette: TonalPalette,
    pub neutral_palette: TonalPalette,
    pub neutral_variant_palette: TonalPalette,
    pub custom_palettes: HashMap<String, TonalPalette>,
}

impl DynamicScheme {
    pub fn new(
        source_color: Lch,
        error_color: Option<Lch>,
        custom_colors: HashMap<String, Lch>,
        variant: Variant,
        contrast_level: f32,
        is_dark: bool,
        harmonize_customs: bool,
    ) -> Self {
        let (
            primary_palette,
            secondary_palette,
            tertiary_palette,
            neutral_palette,
            neutral_variant_palette,
            custom_generator,
        ) = variant.build_palette(source_color, harmonize_customs);

        let custom_palettes = custom_colors
            .into_iter()
            .map(|(name, color)| (name, custom_generator(&color)))
            .collect();

        DynamicScheme {
            source_color,
            error_palette: error_color
                .map(|error_color| {
                    TonalPalette::from_hue_and_chroma(
                        error_color.hue.into_positive_degrees(),
                        error_color.chroma,
                    )
                })
                .unwrap_or_else(|| TonalPalette::from_hue_and_chroma(25.0, 48.0)),
            contrast_level,
            variant,
            is_dark,
            harmonize_customs,
            primary_palette,
            secondary_palette,
            tertiary_palette,
            neutral_palette,
            neutral_variant_palette,
            custom_palettes,
        }
    }
}
